@@ -65,7 +65,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.11.0-P3
+		echo VERSION=9.11.1-P2
 		exit 0
 		;;
 	--cflags)
@@ -156,7 +156,7 @@ if test x"$echo_libs" = x"true"; then
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -ldl -lcap -ljson-c -lpthread -lm -lGeoIP  -L/usr/lib -lxml2 -lz -llzma -lm -ldl"
+		libs="$libs  -ldl -lcap -ljson-c -lpthread -lm -lGeoIP  -L/usr/lib -lxml2 -lz -llzma -licui18n -licuuc -licudata -lm -ldl"
 	fi
 	echo $libs
 fi
